Index: uspace/lib/usb/src/devdrv.c
===================================================================
--- uspace/lib/usb/src/devdrv.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/devdrv.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -147,5 +147,5 @@
 	}
 
-	rc = usb_endpoint_pipe_initialize_from_configuration(dev->pipes,
+	rc = usb_pipe_initialize_from_configuration(dev->pipes,
 	   pipe_count, config_descriptor, config_descriptor_size, &dev->wire);
 	if (rc != EOK) {
@@ -172,5 +172,5 @@
 	for (i = 0; i < pipe_count; i++) {
 		if (dev->pipes[i].present) {
-			rc = usb_endpoint_pipe_register(dev->pipes[i].pipe,
+			rc = usb_pipe_register(dev->pipes[i].pipe,
 			    dev->pipes[i].descriptor->poll_interval,
 			    &hc_conn);
@@ -219,5 +219,5 @@
 	}
 
-	rc = usb_endpoint_pipe_initialize_default_control(&dev->ctrl_pipe,
+	rc = usb_pipe_initialize_default_control(&dev->ctrl_pipe,
 	    &dev->wire);
 	if (rc != EOK) {
@@ -228,5 +228,5 @@
 	}
 
-	rc = usb_endpoint_pipe_probe_default_control(&dev->ctrl_pipe);
+	rc = usb_pipe_probe_default_control(&dev->ctrl_pipe);
 	if (rc != EOK) {
 		usb_log_error(
@@ -240,5 +240,5 @@
 	 * default control pipe.
 	 */
-	rc = usb_endpoint_pipe_start_session(&dev->ctrl_pipe);
+	rc = usb_pipe_start_session(&dev->ctrl_pipe);
 	if (rc != EOK) {
 		usb_log_error("Failed to start an IPC session: %s.\n",
@@ -252,5 +252,5 @@
 
 	/* No checking here. */
-	usb_endpoint_pipe_end_session(&dev->ctrl_pipe);
+	usb_pipe_end_session(&dev->ctrl_pipe);
 
 	return rc;
Index: uspace/lib/usb/src/devpoll.c
===================================================================
--- uspace/lib/usb/src/devpoll.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/devpoll.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -71,5 +71,5 @@
 		int rc;
 
-		rc = usb_endpoint_pipe_start_session(pipe);
+		rc = usb_pipe_start_session(pipe);
 		if (rc != EOK) {
 			failed_attempts++;
@@ -78,9 +78,9 @@
 
 		size_t actual_size;
-		rc = usb_endpoint_pipe_read(pipe, polling_data->buffer,
+		rc = usb_pipe_read(pipe, polling_data->buffer,
 		    polling_data->request_size, &actual_size);
 
 		/* Quit the session regardless of errors. */
-		usb_endpoint_pipe_end_session(pipe);
+		usb_pipe_end_session(pipe);
 
 		if (rc != EOK) {
Index: uspace/lib/usb/src/hub.c
===================================================================
--- uspace/lib/usb/src/hub.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/hub.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -229,5 +229,5 @@
 
 	usb_pipe_t ctrl_pipe;
-	rc = usb_endpoint_pipe_initialize_default_control(&ctrl_pipe,
+	rc = usb_pipe_initialize_default_control(&ctrl_pipe,
 	    &dev_conn);
 	if (rc != EOK) {
@@ -235,5 +235,5 @@
 		goto leave_release_default_address;
 	}
-	rc = usb_endpoint_pipe_probe_default_control(&ctrl_pipe);
+	rc = usb_pipe_probe_default_control(&ctrl_pipe);
 	if (rc != EOK) {
 		rc = ENOTCONN;
@@ -241,5 +241,5 @@
 	}
 
-	rc = usb_endpoint_pipe_start_session(&ctrl_pipe);
+	rc = usb_pipe_start_session(&ctrl_pipe);
 	if (rc != EOK) {
 		rc = ENOTCONN;
@@ -253,5 +253,5 @@
 	}
 
-	usb_endpoint_pipe_end_session(&ctrl_pipe);
+	usb_pipe_end_session(&ctrl_pipe);
 
 	/*
@@ -306,5 +306,5 @@
 
 leave_stop_session:
-	usb_endpoint_pipe_end_session(&ctrl_pipe);
+	usb_pipe_end_session(&ctrl_pipe);
 
 leave_release_default_address:
Index: uspace/lib/usb/src/pipesinit.c
===================================================================
--- uspace/lib/usb/src/pipesinit.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/pipesinit.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -193,5 +193,5 @@
 	}
 
-	int rc = usb_endpoint_pipe_initialize(ep_mapping->pipe, wire,
+	int rc = usb_pipe_initialize(ep_mapping->pipe, wire,
 	    ep_no, description.transfer_type, endpoint->max_packet_size,
 	    description.direction);
@@ -276,5 +276,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_initialize_from_configuration(
+int usb_pipe_initialize_from_configuration(
     usb_endpoint_mapping_t *mapping, size_t mapping_count,
     uint8_t *configuration_descriptor, size_t configuration_descriptor_size,
@@ -342,5 +342,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_initialize(usb_pipe_t *pipe,
+int usb_pipe_initialize(usb_pipe_t *pipe,
     usb_device_connection_t *connection, usb_endpoint_t endpoint_no,
     usb_transfer_type_t transfer_type, size_t max_packet_size,
@@ -367,5 +367,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_initialize_default_control(usb_pipe_t *pipe,
+int usb_pipe_initialize_default_control(usb_pipe_t *pipe,
     usb_device_connection_t *connection)
 {
@@ -373,5 +373,5 @@
 	assert(connection);
 
-	int rc = usb_endpoint_pipe_initialize(pipe, connection,
+	int rc = usb_pipe_initialize(pipe, connection,
 	    0, USB_TRANSFER_CONTROL, CTRL_PIPE_MIN_PACKET_SIZE,
 	    USB_DIRECTION_BOTH);
@@ -390,5 +390,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_probe_default_control(usb_pipe_t *pipe)
+int usb_pipe_probe_default_control(usb_pipe_t *pipe)
 {
 	assert(pipe);
@@ -408,5 +408,5 @@
 
 	TRY_LOOP(failed_attempts) {
-		rc = usb_endpoint_pipe_start_session(pipe);
+		rc = usb_pipe_start_session(pipe);
 		if (rc == EOK) {
 			break;
@@ -433,5 +433,5 @@
 		}
 	}
-	usb_endpoint_pipe_end_session(pipe);
+	usb_pipe_end_session(pipe);
 	if (rc != EOK) {
 		return rc;
@@ -451,5 +451,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_register(usb_pipe_t *pipe,
+int usb_pipe_register(usb_pipe_t *pipe,
     unsigned int interval,
     usb_hc_connection_t *hc_connection)
@@ -479,5 +479,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_unregister(usb_pipe_t *pipe,
+int usb_pipe_unregister(usb_pipe_t *pipe,
     usb_hc_connection_t *hc_connection)
 {
Index: uspace/lib/usb/src/pipesio.c
===================================================================
--- uspace/lib/usb/src/pipesio.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/pipesio.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -58,5 +58,5 @@
  * @return Error code.
  */
-static int usb_endpoint_pipe_read_no_checks(usb_pipe_t *pipe,
+static int usb_pipe_read_no_checks(usb_pipe_t *pipe,
     void *buffer, size_t size, size_t *size_transfered)
 {
@@ -140,5 +140,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_read(usb_pipe_t *pipe,
+int usb_pipe_read(usb_pipe_t *pipe,
     void *buffer, size_t size, size_t *size_transfered)
 {
@@ -153,5 +153,5 @@
 	}
 
-	if (!usb_endpoint_pipe_is_session_started(pipe)) {
+	if (!usb_pipe_is_session_started(pipe)) {
 		return EBADF;
 	}
@@ -168,5 +168,5 @@
 	int rc;
 
-	rc = usb_endpoint_pipe_read_no_checks(pipe, buffer, size, &act_size);
+	rc = usb_pipe_read_no_checks(pipe, buffer, size, &act_size);
 	if (rc != EOK) {
 		return rc;
@@ -190,5 +190,5 @@
  * @return Error code.
  */
-static int usb_endpoint_pipe_write_no_check(usb_pipe_t *pipe,
+static int usb_pipe_write_no_check(usb_pipe_t *pipe,
     void *buffer, size_t size)
 {
@@ -247,5 +247,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_write(usb_pipe_t *pipe,
+int usb_pipe_write(usb_pipe_t *pipe,
     void *buffer, size_t size)
 {
@@ -260,5 +260,5 @@
 	}
 
-	if (!usb_endpoint_pipe_is_session_started(pipe)) {
+	if (!usb_pipe_is_session_started(pipe)) {
 		return EBADF;
 	}
@@ -272,5 +272,5 @@
 	}
 
-	int rc = usb_endpoint_pipe_write_no_check(pipe, buffer, size);
+	int rc = usb_pipe_write_no_check(pipe, buffer, size);
 
 	return rc;
@@ -289,5 +289,5 @@
  * @return Error code.
  */
-static int usb_endpoint_pipe_control_read_no_check(usb_pipe_t *pipe,
+static int usb_pipe_control_read_no_check(usb_pipe_t *pipe,
     void *setup_buffer, size_t setup_buffer_size,
     void *data_buffer, size_t data_buffer_size, size_t *data_transfered_size)
@@ -365,5 +365,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_control_read(usb_pipe_t *pipe,
+int usb_pipe_control_read(usb_pipe_t *pipe,
     void *setup_buffer, size_t setup_buffer_size,
     void *data_buffer, size_t data_buffer_size, size_t *data_transfered_size)
@@ -379,5 +379,5 @@
 	}
 
-	if (!usb_endpoint_pipe_is_session_started(pipe)) {
+	if (!usb_pipe_is_session_started(pipe)) {
 		return EBADF;
 	}
@@ -389,5 +389,5 @@
 
 	size_t act_size = 0;
-	int rc = usb_endpoint_pipe_control_read_no_check(pipe,
+	int rc = usb_pipe_control_read_no_check(pipe,
 	    setup_buffer, setup_buffer_size,
 	    data_buffer, data_buffer_size, &act_size);
@@ -414,5 +414,5 @@
  * @return Error code.
  */
-static int usb_endpoint_pipe_control_write_no_check(usb_pipe_t *pipe,
+static int usb_pipe_control_write_no_check(usb_pipe_t *pipe,
     void *setup_buffer, size_t setup_buffer_size,
     void *data_buffer, size_t data_buffer_size)
@@ -473,5 +473,5 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_control_write(usb_pipe_t *pipe,
+int usb_pipe_control_write(usb_pipe_t *pipe,
     void *setup_buffer, size_t setup_buffer_size,
     void *data_buffer, size_t data_buffer_size)
@@ -491,5 +491,5 @@
 	}
 
-	if (!usb_endpoint_pipe_is_session_started(pipe)) {
+	if (!usb_pipe_is_session_started(pipe)) {
 		return EBADF;
 	}
@@ -500,5 +500,5 @@
 	}
 
-	int rc = usb_endpoint_pipe_control_write_no_check(pipe,
+	int rc = usb_pipe_control_write_no_check(pipe,
 	    setup_buffer, setup_buffer_size, data_buffer, data_buffer_size);
 
Index: uspace/lib/usb/src/recognise.c
===================================================================
--- uspace/lib/usb/src/recognise.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/recognise.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -370,10 +370,10 @@
 	}
 
-	rc = usb_endpoint_pipe_initialize_default_control(&ctrl_pipe,
+	rc = usb_pipe_initialize_default_control(&ctrl_pipe,
 	    &dev_connection);
 	if (rc != EOK) {
 		goto failure;
 	}
-	rc = usb_endpoint_pipe_probe_default_control(&ctrl_pipe);
+	rc = usb_pipe_probe_default_control(&ctrl_pipe);
 	if (rc != EOK) {
 		goto failure;
@@ -404,5 +404,5 @@
 	child->driver_data = dev_data;
 
-	rc = usb_endpoint_pipe_start_session(&ctrl_pipe);
+	rc = usb_pipe_start_session(&ctrl_pipe);
 	if (rc != EOK) {
 		goto failure;
@@ -414,5 +414,5 @@
 	}
 
-	rc = usb_endpoint_pipe_end_session(&ctrl_pipe);
+	rc = usb_pipe_end_session(&ctrl_pipe);
 	if (rc != EOK) {
 		goto failure;
Index: uspace/lib/usb/src/request.c
===================================================================
--- uspace/lib/usb/src/request.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/request.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -42,5 +42,5 @@
 /** Generic wrapper for SET requests using standard control request format.
  *
- * @see usb_endpoint_pipe_control_write
+ * @see usb_pipe_control_write
  *
  * @param pipe Pipe used for the communication.
@@ -90,5 +90,5 @@
 	setup_packet.length = (uint16_t) data_size;
 
-	int rc = usb_endpoint_pipe_control_write(pipe,
+	int rc = usb_pipe_control_write(pipe,
 	    &setup_packet, sizeof(setup_packet),
 	    data, data_size);
@@ -99,5 +99,5 @@
  /** Generic wrapper for GET requests using standard control request format.
   *
-  * @see usb_endpoint_pipe_control_read
+  * @see usb_pipe_control_read
   *
   * @param pipe Pipe used for the communication.
@@ -150,5 +150,5 @@
 	setup_packet.length = (uint16_t) data_size;
 
-	int rc = usb_endpoint_pipe_control_read(pipe,
+	int rc = usb_pipe_control_read(pipe,
 	    &setup_packet, sizeof(setup_packet),
 	    data, data_size, actual_data_size);

Index: uspace/lib/usb/src/pipes.c
===================================================================
--- uspace/lib/usb/src/pipes.c	(revision a3726632dd6e6060c73878c60f6f3087c5bb4016)
+++ uspace/lib/usb/src/pipes.c	(revision 3954a63bd87b69fbec5d8bc2146206516a2c83ea)
@@ -233,5 +233,5 @@
  * A session is something inside what any communication occurs.
  * It is expected that sessions would be started right before the transfer
  * and ended - see usb_endpoint_pipe_end_session() - after the last
  * transfer.
  * The reason for this is that session actually opens some communication
@@ -244,9 +244,9 @@
  * @return Error code.
  */
-int usb_endpoint_pipe_start_session(usb_pipe_t *pipe)
+int usb_pipe_start_session(usb_pipe_t *pipe)
 {
 	assert(pipe);
 
-	if (usb_endpoint_pipe_is_session_started(pipe)) {
+	if (usb_pipe_is_session_started(pipe)) {
 		return EBUSY;
 	}
@@ -265,14 +265,14 @@
 /** Ends a session on the endpoint pipe.
  *
- * @see usb_endpoint_pipe_start_session
+ * @see usb_pipe_start_session
  *
  * @param pipe Endpoint pipe to end the session on.
  * @return Error code.
  */
-int usb_endpoint_pipe_end_session(usb_pipe_t *pipe)
+int usb_pipe_end_session(usb_pipe_t *pipe)
 {
 	assert(pipe);
 
-	if (!usb_endpoint_pipe_is_session_started(pipe)) {
+	if (!usb_pipe_is_session_started(pipe)) {
 		return ENOENT;
 	}
@@ -296,5 +296,5 @@
  * @return Whether @p pipe has opened a session.
  */
-bool usb_endpoint_pipe_is_session_started(usb_pipe_t *pipe)
+bool usb_pipe_is_session_started(usb_pipe_t *pipe)
 {
 	return (pipe->hc_phone >= 0);
@@ -233,5 +233,5 @@
  * A session is something inside what any communication occurs.
  * It is expected that sessions would be started right before the transfer
- * and ended - see usb_endpoint_pipe_end_session() - after the last
+ * and ended - see usb_pipe_end_session() - after the last
  * transfer.
  * The reason for this is that session actually opens some communication